# authentic2_cut - Authentic2 plugin for CUT
# Copyright (C) 2023  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from authentic2_idp_oidc.manager.forms import OIDCClientForm
from django import forms
from django.utils.translation import gettext_lazy as _


class CUTPartnerForm(OIDCClientForm):
    domains = forms.CharField(
        label=_('(Comma-separated) domains'),
        required=False,
        widget=forms.Textarea,
    )
    url = forms.URLField(label=_('Partner URL'), required=False)
    stat_emails = forms.CharField(
        label=_('(Comma-separated) statistics email recipients'),
        required=False,
        widget=forms.Textarea,
    )

    def _clean_array(self, key):
        data = self.cleaned_data[key].replace(' ', '')
        if data:
            return data.split(',')
        return None

    def clean_domains(self):
        return self._clean_array('domains')

    def clean_stat_emails(self):
        return self._clean_array('stat_emails')

    class Meta(OIDCClientForm.Meta):
        fields = OIDCClientForm.Meta.fields + ['domains', 'url', 'stat_emails']
