# authentic2_cut - Authentic2 plugin for CUT
# Copyright (C) 2023  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from authentic2.manager.service_views import ServiceEditView, ServiceSettingsView
from authentic2_idp_oidc.manager.views import OIDCServiceAddView

from .. import models
from . import forms


class CUTPartnerAddView(OIDCServiceAddView):
    form_class = forms.CUTPartnerForm

    def form_valid(self, form):
        response = super().form_valid(form)
        # create associated cut partner
        models.CUTPartner.objects.create(
            oidc_client=self.object,
            domains=form.cleaned_data.get('domains'),
            url=form.cleaned_data.get('url'),
            stat_emails=form.cleaned_data.get('stat_emails'),
        )
        return response


add_cut_partner = CUTPartnerAddView.as_view()


class CUTPartnerEditView(ServiceEditView):
    def get_initial(self):
        initial = super().get_initial()
        if getattr(self.object, 'cut_partner', None):
            cut_partner = self.object.cut_partner
            # pre-populate CUT partner specific fields
            initial['domains'] = cut_partner.domains
            initial['url'] = cut_partner.url
            initial['stat_emails'] = cut_partner.stat_emails
        return initial

    def form_valid(self, form):
        if getattr(self.object, 'cut_partner', None):
            cut_partner = self.object.cut_partner
            # save CUT partner specific fields into dedicated model object
            cut_partner.domains = form.cleaned_data.get('domains', [])
            cut_partner.url = form.cleaned_data.get('url')
            cut_partner.stat_emails = form.cleaned_data.get('stat_emails', [])
            cut_partner.save()

    def get_form_class(self):
        return forms.CUTPartnerForm


edit_cut_partner = CUTPartnerEditView.as_view()


class CUTPartnerSettingsView(ServiceSettingsView):
    template_name = 'authentic2/cut_partner_settings.html'

    def get_context_data(self, **kwargs):
        ctx = super().get_context_data(**kwargs)
        if getattr(self.object, 'cut_partner', None):
            ctx['cut_partner_fields_values'] = {
                'domains': self.object.cut_partner.domains,
                'url': self.object.cut_partner.url,
                'stat_emails': self.object.cut_partner.stat_emails,
            }
        return ctx


cut_partner_settings = CUTPartnerSettingsView.as_view()
