from django.conf import settings
from django.db import migrations


def add_cut_partners(apps, schema_editor):
    cut_partners = getattr(settings, 'A2_CUT_PARTNERS', {})

    OIDCClient = apps.get_model('authentic2_idp_oidc', 'OIDCClient')
    CUTPartner = apps.get_model('authentic2_cut', 'CUTPartner')

    cut_partner_names = [partner['name'] for partner in cut_partners]
    for oidc_client in OIDCClient.objects.filter(name__in=cut_partner_names):
        cut_partner_data = cut_partners[cut_partner_names.index(oidc_client.name)]
        cut_partner = CUTPartner.objects.create(
            oidc_client=oidc_client,
            domains=cut_partner_data['domains'],
            url=cut_partner_data['url'],
            stat_emails=cut_partner_data['stat_emails'],
        )


class Migration(migrations.Migration):

    dependencies = [
        ('authentic2_cut', '0007_cutpartner'),
    ]

    operations = [
        migrations.RunPython(add_cut_partners, reverse_code=migrations.RunPython.noop),
    ]
