# authentic2_cut - Authentic2 plugin for CUT
# Copyright (C) 2017  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from authentic2.decorators import required
from authentic2.manager.utils import manager_login_required
from django.conf.urls import url

from . import api_views, views
from .manager import views as manager_views

urlpatterns = required(
    manager_login_required,
    [
        url('^accounts/edit-core/$', views.edit_core, name='cut-edit-core'),
        url('^accounts/edit-crown/$', views.edit_crown, name='cut-edit-crown'),
        url(r'^manage/users/(?P<pk>\d+)/$', views.manager_user_detail, name='a2-manager-user-detail'),
        url(
            r'^manage/users/uuid:(?P<slug>[a-z0-9]+)/$',
            views.manager_user_detail,
            name='a2-manager-user-by-uuid-detail',
        ),
        url(
            r'^manage/users/(?P<pk>\d+)/edit-core/$',
            views.manager_user_edit_core,
            name='cut-manager-user-edit-core',
        ),
        url('^manage/validation/$', views.validation_homepage, name='cut-manager-user-validation'),
        url('^manage/validation/next/$', views.next_validation, name='cut-manager-user-next-validation'),
        url(r'^manage/validation/(?P<pk>\d+)/$', views.validation, name='cut-manager-user-validation'),
        url(
            r'^manage/validation/attachment/(?P<pk>\d*)/(?P<filename>.*)$',
            views.validation_attachment,
            name='cut-manager-user-validation-attachment',
        ),
        url(
            r'^manage/validation/attachment-thumbnail/(?P<pk>\d*)/(?P<filename>.*)$',
            views.validation_attachment_thumbnail,
            name='cut-manager-user-validation-attachment-thumbnail',
        ),
        # override a2's generic service edition views
        url(
            r'^manage/services/(?P<service_pk>\d*)/settings/$',
            manager_views.cut_partner_settings,
            name='a2-manager-service-settings',
        ),
        url(
            r'^manage/services/(?P<service_pk>\d*)/settings/edit/$',
            manager_views.edit_cut_partner,
            name='a2-manager-service-settings-edit',
        ),
        url(
            r'^manage/services/add-oidc/$',
            manager_views.add_cut_partner,
            name='a2-manager-add-oidc-service',
        ),
    ],
)

urlpatterns += [
    url('^cgu/$', views.cgu, name='cut-cgu'),
    url('^api/validate/$', api_views.validate, name='api-cut-validate'),
]
