def test_migration_0008_migrate_oidcclients_to_cutpartners(transactional_db, migration, settings):
    settings.A2_CUT_PARTNERS = [
        {
            'domains': ['.lyon.fr'],
            'url': 'www.lyon.fr',
            'name': 'Ville de Lyon',
            'stat_emails': ['lyon@example.com'],
        },
        {
            'domains': ['.entrouvert.org'],
            'url': 'www.entrouvert.org',
            'name': 'Entr’ouvert',
            'stat_emails': ['entrouvert@example.com'],
        },
        # partner that does not match an existing oidc client
        {
            'domains': ['.example.com'],
            'url': 'www.example.com',
            'name': 'Example',
            'stat_emails': ['void@example.com'],
        },
    ]

    old_apps = migration.before([('authentic2_cut', '0007_cutpartner')])

    OIDCClient = old_apps.get_model('authentic2_idp_oidc', 'OIDCClient')
    OIDCClient.objects.create(
        name='Ville de Lyon',  # matches A2_CUT_PARTNERS’ first entry
        slug='ville-de-lyon',
        client_id='abc',
        client_secret='def',
    )
    OIDCClient.objects.create(
        name='Entr’ouvert',  # matches A2_CUT_PARTNERS’ second entry
        slug='entrouvert',
        client_id='ghi',
        client_secret='jkl',
    )

    CUTPartner = old_apps.get_model('authentic2_cut', 'CUTPartner')
    assert not CUTPartner.objects.count()

    new_apps = migration.apply([('authentic2_cut', '0008_migrate_oidcclients_to_cutpartners')])
    CUTPartner = new_apps.get_model('authentic2_cut', 'CUTPartner')
    assert CUTPartner.objects.count() == 2

    eo_partner = CUTPartner.objects.get(url='www.entrouvert.org')
    assert eo_partner.domains == ['.entrouvert.org']
    assert eo_partner.stat_emails == ['entrouvert@example.com']

    lyon_partner = CUTPartner.objects.get(url='www.lyon.fr')
    assert lyon_partner.domains == ['.lyon.fr']
    assert lyon_partner.stat_emails == ['lyon@example.com']
